define('oxguard/settings/defaults', [
], function () {
    'use strict';

    function getDefault() {
        return undefined;
    }

    return {
        cryptoProvider: getDefault(),
        enableAutocrypt: true
    };
});
